# SMCP — Solver for sparse matrix cone programs

## Build Status

[![Documentation Status](https://readthedocs.org/projects/smcp/badge/?version=latest)](http://smcp.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/license-GPL3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)

## Documentation

Documentation available at http://smcp.readthedocs.io


## Quick Install

```
pip install smcp
```
